<?xml version="1.0" encoding="UTF-8"?>
<#-- Import common macros and functions -->
<#import "macros_common_general.ftl" as com>
<#import "macros_common_studies_and_summaries.ftl" as studyandsummaryCom>
<#-- Import common macros and functions for CSR Chapter One -->
<#import "common_module_substance_basic_information.ftl" as keySubstanceInformation>
<#import "common_module_substance_composition.ftl" as keyCompositionInformation>
<#import "common_module_nanoforms.ftl" as keyNanoformInformation>
<#import "common_module_assessment_entities.ftl" as keyAssessmentInformation>
<#import "common_module_physical_chemical_summary_properties.ftl" as keyPhysChemInformation>
<#import "common_module_linked_categories.ftl" as keyCategoryInformation>
<#-- Import common macros and functions for CSR Chapter Three -->
<#import "common_module_classification_and_labelling.ftl" as keyClassifcationAndLabellingInformation>
<#-- Import common macros and functions for CSR Chapter Four -->
<#import "common_module_environmental_fate_properties.ftl" as keyEnvironmentalFateAndProperties>
<#-- Import common macros and functions for CSR Chapter Five -->
<#import "common_module_human_health_hazard_assessment.ftl" as keyHumanHealthHazardAssessmentInformation>
<#-- Import common macros and functions for CSR Chapter Six -->
<#import "common_module_human_health_hazard_assessment_of_physicochemical_properties.ftl" as keyHumanHealthHazardAssessmentOfPhysChemPropInformation>
<#-- Import common macros and functions for CSR Chapter Seven -->
<#import "common_module_environmental_hazard_assessment.ftl" as keyEnvironmentalHazardAssessment>
<#-- Import common macros and functions for CSR Chapter Seven -->
<#import "common_module_pnec_assessment.ftl" as keyPNECinformation>
<#-- Import common macros and functions for CSR Chapter Eight -->
<#import "common_module_pbt_and_vpvb_assessment.ftl" as keyPbtandvPvBassessment>


<!-- CSR main template file -->
<#assign locale = "en" />
<#assign sysDateTime = .now>

<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

	<#assign substance = com.getReportSubject(rootDocument) />
		
	<#assign left_header_text = ''/> 
	<#assign central_header_text = com.getReportSubject(rootDocument).name?html />
	<#assign right_header_text = ''/> 
	
	<#assign left_footer_text = sysDateTime?string["dd/MM/yyyy"] + " - IUCLID 6 " + iuclid6Version!/> 
	<#assign central_footer_text = 'Chemical Safety Report' />
	<#assign right_footer_text = ''/> 
		
	<!-- Initialize common variables -->
	<@com.initializeMainVariables/>	
	
	<!-- Initialize assessment entity related lists -->
	<@studyandsummaryCom.initAssessmentEntities _subject/>	
	
	<!-- Initialize the macro and use csrRelevant?? to include or !(csrRelevant??) exclude content from FTLs for the CSR report -->
	<@com.initiRelevanceForCSR relevance/>
	
	<!-- Create variables for simple entities -->
	<#if !isMixture(_subject)>
		<#assign ownerLegalEntity = iuclid.getDocumentForKey(_subject.OwnerLegalEntity) />
		<#assign referenceSubstance = iuclid.getDocumentForKey(_subject.ReferenceSubstance.ReferenceSubstance) />
	</#if>

	<info>
        <title>CHEMICAL SAFETY REPORT</title>
		<cover>
		<@com.emptyLine/>
            <para>
				<para>
				<#if !isMixture(_subject)>
					<emphasis role="bold">Substance Name:</emphasis> <@com.substanceName _subject/>
				<#else>
					<emphasis role="bold">Mixture Name:</emphasis> <@com.text _subject.MixtureName/>
				</#if>
				</para>
				<#if !isMixture(_subject)>
					<#if referenceSubstance?has_content>
						<#if referenceSubstance.Inventory.InventoryEntry?has_content>
						<para>		
							<emphasis role="bold">EC Number:</emphasis>
							<@com.inventoryECNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance)/>
						</para>
						</#if>
						<para>
							<emphasis role="bold">CAS Number:</emphasis>
							<#assign casNumberInv>						
								<@com.inventoryECCasNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance) />
							</#assign>
							<#if casNumberInv?has_content>
								${casNumberInv}
							<#else>							
								<@com.inventoryECNumber com.getReferenceSubstanceKey(_subject.ReferenceSubstance.ReferenceSubstance)/>
							</#if>
						</para>
					</#if>
				</#if>	
				<para>
					<emphasis role="bold">Registrant's Identity: </emphasis><#if ownerLegalEntity?has_content><@com.text ownerLegalEntity.GeneralInfo.LegalEntityName/></#if>
				</para>
			</para>
        </cover>
        <@com.metadataBlock left_header_text central_header_text right_header_text left_footer_text central_footer_text right_footer_text />
    </info>
	
	<!-- Part A -->
	<#if !isMixture(_subject)>
	<part>
		<title>Part A</title>
				
		<#assign recordList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "FLEXIBLE_RECORD", "ChemicalSafetyReport") />
		<#-- print only the first TypeCSRPartA record -->
		<#if recordList?size gt 1>
			<#assign recordList = [recordList[0]]/>
		</#if>
		<#assign printRecordName = false />
				
		<chapter label="1">
						<title role="HEAD-1">SUMMARY OF RISK MANAGEMENT MEASURES</title>
			<#if recordList?has_content>
				<#list recordList as record>
					<#if printRecordName>
						<para><emphasis role="bold"><@com.text record.name/></emphasis></para>
					</#if>
					<@com.richText record.CSRPartA.SummaryRMM/>
					<para>
						The above part A element applies to:
						<#if !(record.CSR.TypeOfCSR)?has_content>
							CSR (all uses)
						<#elseif record.CSR.TypeOfCSR?has_content>
							<@com.picklist record.CSR.TypeOfCSR/>						
						</#if>
					</para>
				</#list>
			</#if>
			
		</chapter>
		<chapter label="2">
			<title role="HEAD-1">DECLARATION THAT RISK MANAGEMENT MEASURES ARE IMPLEMENTED</title>
			
			<#if recordList?has_content>
				<#list recordList as record>
					<#if printRecordName>
						<para><emphasis role="bold"><@com.text record.name/></emphasis></para>
					</#if>
					<@com.richText record.CSRPartA.DeclarationRMMImplemented/>
					<para>
						The above part A element applies to:
						<#if !(record.CSR.TypeOfCSR)?has_content>
							CSR (all uses)
						<#elseif record.CSR.TypeOfCSR?has_content>
							<@com.picklist record.CSR.TypeOfCSR/>						
						</#if>
					</para>
				</#list>
			</#if>
			
		</chapter>
		<chapter label="3">
			<title role="HEAD-1">DECLARATION THAT RISK MANAGEMENT MEASURES ARE COMMUNICATED</title>
			
			<#if recordList?has_content>
				<#list recordList as record>
					<#if printRecordName>
						<para><emphasis role="bold"><@com.text record.name/></emphasis></para>
					</#if>
					<@com.richText record.CSRPartA.DeclarationRMMCommunicated/>
					<para>
						The above part A element applies to:
						<#if !(record.CSR.TypeOfCSR)?has_content>
							CSR (all uses)
						<#elseif record.CSR.TypeOfCSR?has_content>
							<@com.picklist record.CSR.TypeOfCSR/>						
						</#if>
					</para>
				</#list>
			</#if>
		</chapter>
	</part>
	</#if>
	
	<!-- Part B -->
	<part>
		<title>Part B</title>
		
		<chapter label="1">
			<title role="HEAD-1">IDENTITY OF THE SUBSTANCE AND PHYSICAL AND CHEMICAL PROPERTIES</title>
			
			<#include "01_csr_identity_of_the_substance_and_phys_chem_properties.ftl" encoding="UTF-8" />
		</chapter>		

		<#if !isMixture(_subject)>
			<chapter label="2">
				<title role="HEAD-1">MANUFACTURE AND USES</title>
				
				<#include "02_csr_manufacture_and_use.ftl" encoding="UTF-8" />
			</chapter>
		</#if>
		
		<chapter label="3">
			<title role="HEAD-1">CLASSIFICATION AND LABELLING</title>
			
			<#include "03_csr_classification_and_labelling.ftl" encoding="UTF-8" />
		</chapter>

		<chapter label="4">
			<title role="HEAD-1">ENVIRONMENTAL FATE PROPERTIES</title>
			
			<#include "04_csr_environmental_fate_properties.ftl" encoding="UTF-8" />			
		</chapter>
		
		<chapter label="5">
			<title role="HEAD-1">HUMAN HEALTH HAZARD ASSESSMENT</title>
			<#include "05_csr_human_health_hazard_assessment.ftl" encoding="UTF-8" />
		</chapter>

		<chapter label="6">
			<title role="HEAD-1">HUMAN HEALTH HAZARD ASSESSMENT OF PHYSICOCHEMICAL PROPERTIES</title>
			
			<#include "06_csr_human_health_hazard_assessment_of_physicochemical_properties.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="7">
			<title role="HEAD-1">ENVIRONMENTAL HAZARD ASSESSMENT</title>
			
			<#include "07_csr_environmental_hazard_assessment.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="8">
			<title role="HEAD-1">PBT AND vPvB ASSESSMENT</title>
			
			<#include "08_csr_pbt_and_vpvb_assessment.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="9">
			<title role="HEAD-1">EXPOSURE ASSESSMENT (and related risk characterisation)</title>
			<para> No information available. </para>
		</chapter>
		
		<chapter label="10">
			<title role="HEAD-1">RISK CHARACTERISATION RELATED TO COMBINED EXPOSURE</title>
			<para> No information available. </para>
		</chapter>
		
	</part>
	
	<!-- Part B -->
	<part>
		<title>Annexes</title>
		
		<chapter label="1">
			<title role="HEAD-1">Annex: References</title>
			
			<#include "Annex1_literature_references.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="2">
			<title role="HEAD-1">Annex: Information on Test Material</title>
			
			<#include "Annex2_test_materials.ftl" encoding="UTF-8" />
		</chapter>
		
		<chapter label="3">
			<title role="HEAD-1">Annex: Mode of action / Human relevance Framework</title>
			
			<#include "Annex3_mode_of_action.ftl" encoding="UTF-8" />
		</chapter>
	</part>

</book>

<!-- Macros and functions -->
<#function isMixture _subject>
<#if _subject.documentType=="MIXTURE">
	<#return true>
<#else>
	<#return false>
</#if>
	<#return false>
</#function>


